@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/chgrp.c,v 1.9 1997/08/13 12:24:58 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/chgrp.c,v 1.10 2001/02/03 15:58:51 werner Exp $
  *
  * Change Group
  *
@@ -23,7 +23,7 @@ int ChangeFileGroup(FileEntry *fe_ptr)
 
   result = -1;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
@@ -132,7 +132,7 @@ int ChangeDirGroup(DirEntry *de_ptr)
 
   result = -1;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
