@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/chmod.c,v 1.11 2000/05/28 17:48:39 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/chmod.c,v 1.13 2001/04/16 13:34:26 werner Exp $
  *
  * Change Modus
  *
@@ -24,7 +24,7 @@ int ChangeFileModus(FileEntry *fe_ptr)
 
   result = -1;
   
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
@@ -55,7 +55,7 @@ int ChangeDirModus(DirEntry *de_ptr)
 
   result = -1;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
@@ -94,7 +94,7 @@ int GetNewFileModus(int y, int x, char *modus, char *term)
   do
   {
     move( y, x + p );
-    wnoutrefresh( stdscr );
+    RefreshWindow( stdscr );
     doupdate();
 
     c = Getch();
