@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/chown.c,v 1.9 1997/08/13 12:24:58 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/chown.c,v 1.10 2001/02/03 15:58:51 werner Exp $
  *
  * Change Owner
  *
@@ -23,7 +23,7 @@ int ChangeFileOwner(FileEntry *fe_ptr)
 
   result = -1;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
@@ -133,7 +133,7 @@ int ChangeDirOwner(DirEntry *de_ptr)
 
   result = -1;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
