@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/config.h,v 1.19 2000/07/13 18:26:06 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/config.h,v 1.20 2001/02/03 15:58:51 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -11,6 +11,11 @@
 #define DEFAULT_FILEMODE      "2"
 #define DEFAULT_NOSMALLWINDOW "0"
 #define DEFAULT_NUMBERSEP     "."
+#define DEFAULT_INITIALDIR    NULL
+#define DEFAULT_DIR1          NULL
+#define DEFAULT_DIR2          NULL
+#define DEFAULT_FILE1         NULL
+#define DEFAULT_FILE2         NULL
 
 /* UNIX-Kommandos */
 /*----------------*/
