@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/copy.c,v 1.14 2000/06/10 13:15:41 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/copy.c,v 1.16 2001/02/03 15:58:51 werner Exp $
  *
  * Kopieren von Dateien / Verzeichnissen
  *
@@ -36,7 +36,7 @@ int CopyFile(Statistic *statistic_ptr,
   struct stat stat_struct;
   int         term;
   int         result;
-  DIR         *tmpdir;
+  DIR         *tmpdir = NULL;
 
   result = -1;
 
@@ -106,7 +106,9 @@ int CopyFile(Statistic *statistic_ptr,
      }
      else
      {
-        closedir(tmpdir);
+        if( tmpdir)
+	  closedir(tmpdir);
+
         return ( result );
      }
   }
@@ -296,7 +298,7 @@ static int Copy(char *to_path, char *from_path)
   int         i, o, n;
   char        buffer[2048];
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     return( CopyArchiveFile( to_path, from_path ) );
   }
