@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/edit.c,v 1.11 1997/12/27 16:07:35 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/edit.c,v 1.12 2001/02/03 15:58:51 werner Exp $
  *
  * Edit-Kommando-Bearbeitung
  *
@@ -18,7 +18,7 @@ int Edit(char *file_path)
   int  result = -1;
   char *file_p_aux=NULL;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( -1 );
