@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/error.c,v 1.10 1997/08/13 12:24:58 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/error.c,v 1.11 2001/04/16 13:34:26 werner Exp $
  *
  * Ausgabe von Fehlermeldungen
  *
@@ -32,7 +32,7 @@ void Notice(char *msg)
 {
   MapNoticeWindow( "N O T I C E" );
   DisplayErrorMessage( msg );
-  wnoutrefresh( error_window );
+  RefreshWindow( error_window );
   refresh();
 }
 
@@ -170,7 +170,7 @@ static int PrintErrorMessage(char *msg)
   
   DisplayErrorMessage( msg );
   beep();
-  wnoutrefresh( error_window );
+  RefreshWindow( error_window );
   doupdate();
   c = wgetch(error_window);
   UnmapErrorWindow();
