@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/execute.c,v 1.9 1997/12/27 16:07:35 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/execute.c,v 1.10 2001/02/03 15:58:51 werner Exp $
  *
  * Ausfuehren von System-Kommandos
  *
@@ -43,7 +43,7 @@ int Execute(DirEntry *dir_entry, FileEntry *file_entry)
       (void) strcpy( cwd, "." );
     }
 
-    if( mode == DISK_MODE )
+    if( mode == DISK_MODE || mode == USER_MODE )
     {
       if( chdir( GetPath( dir_entry, path ) ) )
       {
