@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.23 2000/07/13 18:26:06 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.25 2001/04/16 13:34:26 werner Exp $
  *
  * Funktionen zur Handhabung des FILE-Windows
  *
@@ -74,28 +74,29 @@ void SetFileMode(int new_file_mode)
   {
     case MODE_1: if( max_linkname_len)
 		   max_column = window_width / 
-				(max_filename_len + max_linkname_len + 44); 
+				(max_filename_len + max_linkname_len + 45); 
 		 else
-		   max_column = window_width / (max_filename_len + 40); 
+		   max_column = window_width / (max_filename_len + 41); 
 		 break;
     case MODE_2: if( max_linkname_len)
 		   max_column = window_width / 
-                   (max_filename_len + max_linkname_len + 44);
+                   (max_filename_len + max_linkname_len + 41);
 		 else
-                   max_column = window_width / (max_filename_len + 40);
+                   max_column = window_width / (max_filename_len + 37);
 		 break;
-    case MODE_3: max_column = window_width / (max_filename_len + 4);  break;
+    case MODE_3: max_column = window_width / (max_filename_len + 3);  
+    		 break;
     case MODE_4: if( max_linkname_len)
 		   max_column = window_width / 
-				(max_filename_len + max_linkname_len + 47); 
+				(max_filename_len + max_linkname_len + 44); 
 		 else
-		   max_column = window_width / (max_filename_len + 43); 
+		   max_column = window_width / (max_filename_len + 40); 
 		 break;
     case MODE_5: max_userview_len = GetUserFileEntryLength(max_filename_len, 
 					                   max_linkname_len, 
 					                   USERVIEW);
                  if(max_userview_len)
-		   max_column = window_width / max_userview_len;
+		   max_column = window_width / (max_userview_len + 1);
 		 else
 		   max_column = 0;
 		 break;
@@ -111,13 +112,13 @@ void RotateFileMode(void)
 {
   switch( file_mode )
   {
-    case MODE_1: SetFileMode( MODE_2 ); break;
-    case MODE_2: SetFileMode( MODE_4 ); break;
-    case MODE_3: SetFileMode( MODE_1 ); break;
-    case MODE_4: SetFileMode( MODE_5 ); break;
-    case MODE_5: SetFileMode( MODE_3 ); break;
+    case MODE_1: SetFileMode( MODE_3 ); break;
+    case MODE_2: SetFileMode( MODE_5 ); break;
+    case MODE_3: SetFileMode( MODE_4 ); break;
+    case MODE_4: SetFileMode( MODE_2 ); break;
+    case MODE_5: SetFileMode( MODE_1 ); break;
   }
-  if( (mode != DISK_MODE ) && file_mode == MODE_4 ) {
+  if( (mode != DISK_MODE && mode != USER_MODE) && file_mode == MODE_4 ) {
     RotateFileMode();
   } else if(file_mode == MODE_5 && !strcmp(USERVIEW, "")) {
     RotateFileMode();
@@ -127,69 +128,113 @@ void RotateFileMode(void)
 
 
 
-
-static void BuildFileEntryList(DirEntry *dir_entry)
+static void ReadTaggedList(DirEntry *dir_entry)
 {
-  if( file_entry_list ) 
-  {
-    free( file_entry_list );
-    file_entry_list = NULL;
-  }
+  FileEntry *fe_ptr;
+  unsigned int name_len;
+  unsigned int linkname_len;
 
-  if( !dir_entry->global_flag )
-  {
-    /* ... fuer !ANSI-Systeme ... */
-    /*----------------------------*/
+  max_filename_len = 0;
+  max_linkname_len = 0;
 
-    if( dir_entry->matching_files == 0 )
+  for( fe_ptr = dir_entry->file; fe_ptr; fe_ptr = fe_ptr->next )    
+  {
+    if (( fe_ptr->matching ) && ( fe_ptr->tagged ))
     {
-      file_entry_list = NULL;
-    }
-    else
-    {
-      if( ( file_entry_list = (FileEntryList *) 
-	  		      calloc( dir_entry->matching_files,
-				      sizeof( FileEntryList )
-				    ) ) == NULL )
+      file_entry_list[file_count++].file = fe_ptr;
+      name_len = strlen( fe_ptr->name );
+      if( S_ISLNK( fe_ptr->stat_struct.st_mode ) )
       {
-        ERROR_MSG( "Calloc Failed*ABORT" );
-        exit( 1 );
+	linkname_len = strlen( &fe_ptr->name[name_len+1] );
+	max_linkname_len = MAX( max_linkname_len, linkname_len );
       }
+      max_filename_len = MAX( max_filename_len, name_len );
     }
-    file_count = 0;
-    ReadFileList( dir_entry );
-    SortFileEntryList();
-    SetFileMode( file_mode ); /* recalc */
   }
-  else
-  {
-    if( statistic.disk_matching_files == 0 )
-    {
-      file_entry_list = NULL;
-    }
-    else
-    {
-      if( ( file_entry_list = (FileEntryList *) 
-	  		      calloc( statistic.disk_matching_files,
-				      sizeof( FileEntryList )
-				    ) ) == NULL )
-      {
-        ERROR_MSG( "Calloc Failed*ABORT" );
-        exit( 1 );
-      }
-    }
+}
 
-    file_count = 0;
-    global_max_filename_len = 0;
-    global_max_linkname_len = 0;
-    ReadGlobalFileList( statistic.tree );
-    SortFileEntryList();
-    SetFileMode( file_mode ); /* recalc */
+static void ReadTaggedFileList(DirEntry *dir_entry)
+{
+  DirEntry  *de_ptr;
+
+  for( de_ptr=dir_entry; de_ptr; de_ptr=de_ptr->next )
+  {
+    if( de_ptr->sub_tree ) ReadTaggedFileList( de_ptr->sub_tree );
+    ReadTaggedList( de_ptr );
+    global_max_filename_len = MAX( global_max_filename_len, max_filename_len );
+    global_max_linkname_len = MAX( global_max_linkname_len, max_linkname_len );
   }
+  max_filename_len = global_max_filename_len;
+  max_linkname_len = global_max_linkname_len;
 }
 
 
 
+static void BuildFileEntryList(DirEntry *dir_entry){
+
+  if( file_entry_list ) {
+    free( file_entry_list );
+    file_entry_list = NULL;
+  }
+  if( !dir_entry->global_flag )  {
+     /* ... fuer !ANSI-Systeme ... */
+     /*----------------------------*/
+     if( dir_entry->matching_files == 0 )    {
+        file_entry_list = NULL;
+     } else {
+        if( ( file_entry_list = (FileEntryList *) 
+	  		      calloc( dir_entry->matching_files,
+				      sizeof( FileEntryList )
+				    ) 
+                              ) == NULL ) {
+        ERROR_MSG( "Calloc Failed*ABORT" );
+        exit( 1 );
+        }
+     }
+     file_count = 0;
+     ReadFileList( dir_entry );
+     SortFileEntryList();
+     SetFileMode( file_mode ); /* recalc */
+  }  else if (!dir_entry->tagged_flag)  {
+     	if( statistic.disk_matching_files == 0 ) {
+           file_entry_list = NULL;
+        } else {
+           if( ( file_entry_list = (FileEntryList *) 
+	  		      calloc( statistic.disk_matching_files,
+				      sizeof( FileEntryList )
+				    ) ) 
+                              == NULL )  {
+           ERROR_MSG( "Calloc Failed*ABORT" );
+           exit( 1 );
+           }
+        }
+        file_count = 0;
+        global_max_filename_len = 0;
+        global_max_linkname_len = 0;
+        ReadGlobalFileList( statistic.tree );
+        SortFileEntryList();
+        SetFileMode( file_mode ); /* recalc */
+  } else  {
+     if( statistic.disk_matching_files == 0 ) {
+        file_entry_list = NULL;
+     } else {
+        if( ( file_entry_list = (FileEntryList *) 
+	  		      calloc( statistic.disk_tagged_files,
+				      sizeof( FileEntryList )
+				    ) ) 
+                              == NULL )  {
+            ERROR_MSG( "Calloc Failed*ABORT" );
+            exit( 1 );
+        }
+     }
+     file_count = 0;
+     global_max_filename_len = 0;
+     global_max_linkname_len = 0;
+     ReadTaggedFileList( statistic.tree );
+     SortFileEntryList();
+     SetFileMode( file_mode ); /* recalc */
+  }
+}
 
 
 static void ReadFileList(DirEntry *dir_entry)
@@ -474,6 +519,23 @@ static void ChangeFileEntry(void)
 }
 
 
+char GetTypeOfFile(struct stat fst)
+{
+	if ( S_ISLNK(fst.st_mode) )
+		return '@';
+	else if ( S_ISSOCK(fst.st_mode) )
+		return '=';
+	else if ( S_ISCHR(fst.st_mode) )
+		return '-';
+	else if ( S_ISBLK(fst.st_mode) )
+		return '+';
+	else if ( S_ISFIFO(fst.st_mode) )
+		return '|';
+	else if ( S_ISREG(fst.st_mode) )
+		return ' ';
+	else
+		return '?';
+}
 
 
 static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, int start_x)
@@ -495,6 +557,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   char *group_name_ptr;
   int  ef_window_width;
   char *sym_link_name = NULL;
+  char type_of_file = ' ';
 
 
   ef_window_width = window_width - 2; /* Effektive Window-Weite */
@@ -521,6 +584,8 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
     sym_link_name = "";
 
 
+  type_of_file = GetTypeOfFile(fe_ptr->stat_struct);
+  
   switch( file_mode )
   {
     case MODE_1 : if( fe_ptr )
@@ -531,16 +596,19 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		        
 		    (void) CTime( fe_ptr->stat_struct.st_mtime, modify_time );
   
+		    
+		    
                     if( S_ISLNK( fe_ptr->stat_struct.st_mode ) )
 		    {
 #ifdef HAS_LONGLONG
-		      (void) sprintf( format, "%%c%%+%ds %%10s %%3d %%11lld %%12s -> %%-%ds", 
+		      (void) sprintf( format, "%%c%%c%%-%ds %%10s %%3d %%11lld %%12s -> %%-%ds", 
 				      max_filename_len,
 				      max_linkname_len
 				    );
 		      
 		      (void) sprintf( line_buffer, format,
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file, 
 				      fe_ptr->name,
 				      attributes,
 				      fe_ptr->stat_struct.st_nlink,
@@ -549,13 +617,14 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 				      sym_link_name
 				    );
 #else
-		      (void) sprintf( format, "%%c%%+%ds %%10s %%3d %%7d %%12s -> %%-%ds", 
+		      (void) sprintf( format, "%%c%%c%%-%ds %%10s %%3d %%7d %%12s -> %%-%ds", 
 				      max_filename_len,
 				      max_linkname_len
 				    );
     
 		      (void) sprintf( line_buffer, format,
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
 				      fe_ptr->name,
 				      attributes,
 				      fe_ptr->stat_struct.st_nlink,
@@ -568,13 +637,14 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		    else
 		    {
 #ifdef HAS_LONGLONG
-		      (void) sprintf( format, "%%c%%%c%ds %%10s %%3d %%11lld %%12s", 
+		      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%3d %%11lld %%12s", 
                                       justify,
 				      max_filename_len 
 				    );
     
 		      (void) sprintf( line_buffer, format,
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
 				      fe_ptr->name,
 				      attributes,
 				      fe_ptr->stat_struct.st_nlink,
@@ -582,13 +652,14 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 				      modify_time
 				    );
 #else
-		      (void) sprintf( format, "%%c%%%c%ds %%10s %%3d %%7d %%12s", 
+		      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%3d %%7d %%12s", 
                                       justify,
 				      max_filename_len 
 				    );
     
 		      (void) sprintf( line_buffer, format,
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
 				      fe_ptr->name,
 				      attributes,
 				      fe_ptr->stat_struct.st_nlink,
@@ -635,35 +706,71 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   
                     if( S_ISLNK( fe_ptr->stat_struct.st_mode ) )
 		    {
-                      (void) sprintf( format, "%%c%%%c%ds %%10s %%5d  %%-8s  %%-8s -> %%-%ds",
+#ifdef HAS_LONGLONG
+                      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%7lld %%-8s %%-8s -> %%-%ds",
                                       justify,
 			              max_filename_len,
 			              max_linkname_len
 				      );
 		      (void) sprintf( line_buffer, format,
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
 				      fe_ptr->name,
 				      attributes,
-				      fe_ptr->stat_struct.st_ino,
+				      (LONGLONG)fe_ptr->stat_struct.st_ino,
 				      owner_name_ptr,
 				      group_name_ptr,
 				      sym_link_name
 				    );
+#else
+                      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%5d  %%-8s  %%-8s -> %%-%ds",
+                                      justify,
+			              max_filename_len,
+			              max_linkname_len
+				      );
+		      (void) sprintf( line_buffer, format,
+				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
+				      fe_ptr->name,
+				      attributes,
+				      (int)fe_ptr->stat_struct.st_ino,
+				      owner_name_ptr,
+				      group_name_ptr,
+				      sym_link_name
+				    );
+#endif
                     }
 		    else
 		    {
-                      (void) sprintf( format, "%%c%%%c%ds %%10s %%5d  %%-8s  %%-8s",
+#ifdef HAS_LONGLONG
+                      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%7lld %%-8s %%-8s",
                                       justify,
 			              max_filename_len
 				      );
 		      (void) sprintf( line_buffer, format,
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
 				      fe_ptr->name,
 				      attributes,
-				      fe_ptr->stat_struct.st_ino,
+				      (LONGLONG)fe_ptr->stat_struct.st_ino,
 				      owner_name_ptr,
 				      group_name_ptr
 				    );
+#else
+                      (void) sprintf( format, "%%c%%c%%%c%ds %%10s %%5d  %%-8s  %%-8s",
+                                      justify,
+			              max_filename_len
+				      );
+		      (void) sprintf( line_buffer, format,
+				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
+				      fe_ptr->name,
+				      attributes,
+				      (int)fe_ptr->stat_struct.st_ino,
+				      owner_name_ptr,
+				      group_name_ptr
+				    );
+#endif
 
                     }				    
 	          }
@@ -672,24 +779,25 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		    /* Leer-Eintrag */
 		    /*--------------*/
 
-		    (void) sprintf( format, "%%-%ds", max_filename_len + 39 );
+		    (void) sprintf( format, "%%-%ds", max_filename_len + 37 );
 		    (void) sprintf( line_buffer, format, "" );
 		  }
 
 		  if( max_linkname_len ) 
-                    pos_x = x * (max_filename_len + max_linkname_len + 44);
+                    pos_x = x * (max_filename_len + max_linkname_len + 41);
 		  else                   
-                    pos_x = x * (max_filename_len + 40);
+                    pos_x = x * (max_filename_len + 37);
 		  break;
     
     case MODE_3 : if( fe_ptr )
 		  {
-		    (void) sprintf( format, "%%c%%%c%ds", 
+		    (void) sprintf( format, "%%c%%c%%%c%ds", 
                                     justify, 
                                     max_filename_len );
 
 		    (void) sprintf( line_buffer, format,
 				    (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				    type_of_file,
 				    fe_ptr->name
 				  );
                   }
@@ -702,7 +810,7 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		    (void) sprintf( line_buffer, format, "" );
 		  }
 
-		  pos_x = x * (max_filename_len + 4); 
+		  pos_x = x * (max_filename_len + 3); 
 		  break;
     
     case MODE_4 : if( fe_ptr )
@@ -712,13 +820,14 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
   
                     if( S_ISLNK( fe_ptr->stat_struct.st_mode ) )
 		    {
-                      (void) sprintf( format, "%%c%%%c%ds Chg: %%12s  Acc: %%12s -> %%-%ds",
+                      (void) sprintf( format, "%%c%%c%%%c%ds Chg: %%12s  Acc: %%12s -> %%-%ds",
                                       justify,
 				      max_filename_len,
 				      max_linkname_len
 				    );
 		      (void) sprintf( line_buffer, format,
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
 				      fe_ptr->name,
 				      change_time,
 				      access_time,
@@ -727,12 +836,13 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
                     }
 		    else
 		    {
-                      (void) sprintf( format, "%%c%%%c%ds Chg: %%12s  Acc: %%12s",
+                      (void) sprintf( format, "%%c%%c%%%c%ds Chg: %%12s  Acc: %%12s",
                                       justify,
 				      max_filename_len
 				    );
 		      (void) sprintf( line_buffer, format,
 				      (fe_ptr->tagged) ? TAGGED_SYMBOL : ' ',
+				      type_of_file,
 				      fe_ptr->name,
 				      change_time,
 				      access_time
@@ -744,15 +854,15 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		    /* Leer-Eintrag */
 		    /*--------------*/
 
-		    (void) sprintf( format, "%%-%ds", max_filename_len + 41 );
+		    (void) sprintf( format, "%%-%ds", max_filename_len + 40 );
 		    (void) sprintf( line_buffer, format, "" );
 		  }
 
 
 		  if( max_linkname_len ) 
-		    pos_x = x * (max_filename_len + max_linkname_len + 47); 
+		    pos_x = x * (max_filename_len + max_linkname_len + 44); 
 		  else                   
-		    pos_x = x * (max_filename_len + 43); 
+		    pos_x = x * (max_filename_len + 40); 
 		  break;
     
     case MODE_5 : if( fe_ptr )
@@ -766,10 +876,10 @@ static void PrintFileEntry(int entry_no, int y, int x, unsigned char hilight, in
 		    /* Leer-Eintrag */
 		    /*--------------*/
 
-		    (void) sprintf( format, "%%-%ds", max_userview_len );
+		    (void) sprintf( format, "%%-%ds", max_userview_len + 1 );
 		    (void) sprintf( line_buffer, format, "" );
 		  }
-		  pos_x = x * max_userview_len;
+		  pos_x = x * (max_userview_len + 1);
 		  break;
 
   }
@@ -1256,7 +1366,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 
   BuildFileEntryList( dir_entry );
   
-  if( dir_entry->global_flag || dir_entry->big_window )
+  if( dir_entry->global_flag || dir_entry->big_window || dir_entry->tagged_flag)
   {
     SwitchToBigFileWindow();
     GetMaxYX( file_window, &window_height, &window_width );
@@ -1304,8 +1414,8 @@ int HandleFileWindow(DirEntry *dir_entry)
       else              
         DisplayFileParameter( fe_ptr );
 
-      wnoutrefresh( dir_window ); /* needed: ncurses-bug ? */
-      wnoutrefresh( file_window );
+      RefreshWindow( dir_window ); /* needed: ncurses-bug ? */
+      RefreshWindow( file_window );
       doupdate();
       ch = (resize_request) ? -1 : Getch();
       if( ch == LF ) ch = CR;
@@ -1327,7 +1437,7 @@ int HandleFileWindow(DirEntry *dir_entry)
        statistic.cursor_pos--;
        statistic.disp_begin_pos++;
      }
-     if(dir_entry->global_flag || dir_entry->big_window) {
+     if(dir_entry->global_flag || dir_entry->big_window || dir_entry->tagged_flag) {
 
        /* big window active */
 
@@ -1392,6 +1502,9 @@ int HandleFileWindow(DirEntry *dir_entry)
      }
    }
 
+   if (mode == USER_MODE) { /* FileUserMode returns (possibly remapped) ch, or -1 if it handles ch */
+      ch = FileUserMode(&(file_entry_list[dir_entry->start_file + dir_entry->cursor_pos]), ch);
+   }
 
    switch( ch )
    {
@@ -1490,7 +1603,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      break;
 
       case 'A' & 0x1F :
-		      if( mode != DISK_MODE || !IsMatchingTaggedFiles() )
+		      if( (mode != DISK_MODE && mode != USER_MODE) || !IsMatchingTaggedFiles() )
 		      {
 			beep();
 		      }
@@ -1543,7 +1656,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      break;
 
       case 'O' & 0x1F :
-		      if( mode != DISK_MODE || !IsMatchingTaggedFiles() )
+		      if(( mode != DISK_MODE && mode != USER_MODE) || !IsMatchingTaggedFiles() )
 		      {
 			beep();
 		      }
@@ -1585,7 +1698,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      break;
 
       case 'G' & 0x1F :
-		      if( mode != DISK_MODE || !IsMatchingTaggedFiles() )
+		      if(( mode != DISK_MODE && mode != USER_MODE) || !IsMatchingTaggedFiles() )
 		      {
 			beep();
 		      }
@@ -1854,7 +1967,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 			break;
 		      }
 
-		      if( mode == DISK_MODE )
+		      if( mode == DISK_MODE || mode == USER_MODE )
 		      {
                         if( (tmp2 = GetDirEntry( statistic.tree,
 				         de_ptr, 
@@ -1974,7 +2087,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		        }
 
 
-			if( mode == DISK_MODE )
+			if( mode == DISK_MODE || mode == USER_MODE )
 			{
                           if( GetDirEntry( statistic.tree,
 					   de_ptr, 
@@ -2072,7 +2185,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      break;
 
       case 'M' :
-      case 'm' :      if( mode != DISK_MODE )
+      case 'm' :      if( mode != DISK_MODE && mode != USER_MODE )
                       {
 			beep();
 			break;
@@ -2141,7 +2254,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      break;	
 
       case 'N' & 0x1F :
-		      if( mode != DISK_MODE || !IsMatchingTaggedFiles() )
+		      if(( mode != DISK_MODE && mode != USER_MODE) || !IsMatchingTaggedFiles() )
 		      {
 			beep();
 		      }
@@ -2202,7 +2315,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      break;
 
       case 'D' :
-      case 'd' :      if( mode != DISK_MODE )
+      case 'd' :      if( mode != DISK_MODE && mode != USER_MODE )
 		      {
 			beep();
 			break;
@@ -2254,7 +2367,7 @@ int HandleFileWindow(DirEntry *dir_entry)
                       break;	
 
       case 'D' & 0x1F :
-		      if( mode != DISK_MODE || !IsMatchingTaggedFiles() )
+		      if(( mode != DISK_MODE && mode != USER_MODE) || !IsMatchingTaggedFiles() )
 		      {
 			beep();
 		      }
@@ -2276,7 +2389,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      break;	
 
       case 'R':
-      case 'r':       if( mode != DISK_MODE )
+      case 'r':       if( mode != DISK_MODE && mode != USER_MODE )
 		      {
 			beep();
 			break;
@@ -2309,7 +2422,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      break;
 			  
       case 'R' & 0x1F :
-		      if( mode != DISK_MODE || !IsMatchingTaggedFiles() )
+		      if(( mode != DISK_MODE && mode != USER_MODE) || !IsMatchingTaggedFiles() )
 		      {
 			beep();
 		      }
@@ -2392,7 +2505,7 @@ int HandleFileWindow(DirEntry *dir_entry)
       case 'l':
 #endif /* VI_KEYS */
       case 'L':      fe_ptr = file_entry_list[dir_entry->start_file + dir_entry->cursor_pos].file;
-		     if( mode == DISK_MODE )
+		     if( mode == DISK_MODE || mode == USER_MODE )
 		     {
 		       (void) GetFileNamePath( fe_ptr, new_login_path );
                        if( !GetNewLoginPath( new_login_path ) )
@@ -2438,9 +2551,9 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      {
 			beep();
 		      }
-		      else if( mode != DISK_MODE )
+		      else if( mode != DISK_MODE && mode != USER_MODE )
 		      {
-			MESSAGE( "i am sorry*^P not supportet in Archive-mode" );
+			MESSAGE( "i am sorry*^P not supported in Archive-mode" );
 		      }
 		      else
 		      {
@@ -2499,9 +2612,9 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      {
 			beep();
 		      }
-		      else if( mode != DISK_MODE )
+		      else if( mode != DISK_MODE && mode != USER_MODE )
 		      {
-			MESSAGE( "i am sorry*^X not supportet in Archive-mode" );
+			MESSAGE( "i am sorry*^X not supported in Archive-mode" );
 		      }
 		      else
 		      {
@@ -2560,6 +2673,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 
   if(ch != LOGIN_ESC) {
     dir_entry->global_flag = FALSE;
+    dir_entry->tagged_flag = FALSE;
     dir_entry->big_window  = FALSE;
   }
 
@@ -2636,7 +2750,7 @@ static void WalkTaggedFiles(int start_file,
       else              
         DisplayFileParameter( fe_ptr );
       
-      wnoutrefresh( file_window );
+      RefreshWindow( file_window );
       doupdate();
       result = fkt( fe_ptr, walking_package );
       if( walking_package->new_fe_ptr != fe_ptr )
@@ -2744,7 +2858,7 @@ static int DeleteTaggedFiles(int max_disp_files)
       else              
         DisplayFileParameter( fe_ptr );
       
-      wnoutrefresh( file_window );
+      RefreshWindow( file_window );
       doupdate();
    
       if( confirm ) term = InputChoise( "Delete this file (Y/N) ? ", "YN\033" );
