@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/hex.c,v 1.11 1998/07/26 21:21:13 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/hex.c,v 1.12 2001/02/03 15:58:51 werner Exp $
  *
  * View-Hex-Kommando-Bearbeitung
  *
@@ -20,7 +20,8 @@ int ViewHex(char *file_path)
 {
   switch( mode )
   {
-    case DISK_MODE :     return( ViewHexFile( file_path ) );
+    case DISK_MODE :
+    case USER_MODE :     return( ViewHexFile( file_path ) );
     case TAPE_MODE : 
     case RPM_FILE_MODE : 
     case TAR_FILE_MODE : 
