@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/init.c,v 1.17 2000/07/13 18:26:06 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/init.c,v 1.19 2001/04/16 13:34:26 werner Exp $
  *
  * Initialisierungen
  *
@@ -19,10 +19,10 @@ static WINDOW *Newwin(int nlines, int ncols,
 char *XCursesProgramName = "ytree";
 #endif
 
-int Init(void)
+int Init(char *configuration_file, char *history_file)
 {
   char buffer[PATH_LENGTH + 1];
-  char *home;
+  char *home = NULL;
 
   user_umask = umask(0);
   initscr();
@@ -58,9 +58,17 @@ int Init(void)
     exit( 1 );
   }
 
-  if( ( home = getenv("HOME") ) ) {
+  if (configuration_file != NULL) {
+    ReadProfile(configuration_file);
+  }
+  else if( ( home = getenv("HOME") ) ) {
     sprintf(buffer, "%s%c%s", home, FILE_SEPARATOR_CHAR, PROFILE_FILENAME);
     ReadProfile(buffer);
+  }
+  if (history_file != NULL) {
+    ReadHistory(history_file);
+  }
+  else if ( home ) {
     sprintf(buffer, "%s%c%s", home, FILE_SEPARATOR_CHAR, HISTORY_FILENAME);
     ReadHistory(buffer);
   }
@@ -69,6 +77,7 @@ int Init(void)
   SetKindOfSort( SORT_BY_NAME );
   number_seperator = *(NUMBERSEP);
   bypass_small_window = (BOOL)strtod(NOSMALLWINDOW, NULL );
+  initial_directory = INITIALDIR;
 
   InitClock();
 
