@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/login.c,v 1.16 2000/01/01 23:13:53 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/login.c,v 1.18 2001/04/16 13:34:26 werner Exp $
  *
  * Dateibaum lesen
  *
@@ -57,7 +57,7 @@ int LoginDisk(char *path)
   int    status;
   int    result = 0;
 
-  if( mode == DISK_MODE) 
+  if( mode == DISK_MODE || mode == USER_MODE) 
   {
     /* Status retten */
     /*---------------*/
@@ -76,7 +76,14 @@ int LoginDisk(char *path)
       if( statistic.tree != disk_statistic.tree ) 
         DeleteTree( statistic.tree );
 
-      mode = DISK_MODE;
+      if (IsUserActionDefined())
+      {
+        mode = USER_MODE;
+      }
+      else
+      {
+        mode = DISK_MODE;
+      }
       (void) memcpy( (char *) &statistic,
                      (char *) &disk_statistic,
                      sizeof( Statistic )
@@ -98,7 +105,7 @@ int LoginDisk(char *path)
   }
 
 
-  if( mode != DISK_MODE ) 
+  if( mode != DISK_MODE && mode != USER_MODE ) 
   {
     DeleteTree( statistic.tree ); 
   }
@@ -150,6 +157,10 @@ int LoginDisk(char *path)
       default:              mode = TAR_FILE_MODE; break;
     }
   }
+  else if (IsUserActionDefined())
+  {
+    mode = USER_MODE;
+  }
   else
   {
     mode = DISK_MODE;
@@ -162,8 +173,8 @@ int LoginDisk(char *path)
 			   &statistic.disk_capacity
 			 );
 
-  wnoutrefresh( stdscr );
-  wnoutrefresh( dir_window );
+  RefreshWindow( stdscr );
+  RefreshWindow( dir_window );
   DisplayMenu();
   doupdate();
 
@@ -180,7 +191,7 @@ int LoginDisk(char *path)
   }
 
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE)
   {
     (void) strcpy( statistic.tree->name, path );
    
