@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/mkdir.c,v 1.12 2000/06/10 13:15:41 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/mkdir.c,v 1.13 2001/02/03 15:58:51 werner Exp $
  *
  * Erstellen von Verzeichnissen
  *
@@ -17,7 +17,7 @@ int MakeDirectory(DirEntry *father_dir_entry)
   char dir_name[PATH_LENGTH+1];
   int result = -1;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
@@ -49,7 +49,7 @@ int MakeDirEntry(DirEntry *father_dir_entry, char *dir_name )
   struct stat stat_struct;
   int result = -1;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
