@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/pipe.c,v 1.11 1997/12/27 16:07:35 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/pipe.c,v 1.12 2001/02/03 15:58:51 werner Exp $
  *
  * Umlenken von Datei-Inhalten zu einem Kommando
  *
@@ -53,7 +53,7 @@ int Pipe(DirEntry *dir_entry, FileEntry *file_entry)
     (void) GetPath( dir_entry, path );
       
 
-    if( mode == DISK_MODE )
+    if( mode == DISK_MODE || mode == USER_MODE )
     {
       /* Kommandozeile zusammenbasteln */
       /*-------------------------------*/
