@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/rename.c,v 1.10 1997/08/13 12:24:58 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/rename.c,v 1.11 2001/02/03 15:58:51 werner Exp $
  *
  * Umbenennen von Dateien/Verzeichnissen
  *
@@ -236,7 +236,7 @@ int GetRenameParameter(char *old_name, char *new_name)
 {
   int l;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( -1 );
