@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/rmdir.c,v 1.9 1997/08/13 12:24:58 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/rmdir.c,v 1.10 2001/02/03 15:58:51 werner Exp $
  *
  * Loeschen von Verzeichnissen
  *
@@ -20,7 +20,7 @@ int DeleteDirectory(DirEntry *dir_entry)
   char buffer[PATH_LENGTH+1];
   int result = -1;
 
-  if( mode != DISK_MODE )
+  if( mode != DISK_MODE && mode != USER_MODE )
   {
     beep();
     return( result );
