@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.23 2000/07/13 18:26:06 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.25 2001/04/16 13:34:27 werner Exp $
  *
  * Diverse Hilfsfunktionen
  *
@@ -62,7 +62,7 @@ char *GetRealFileNamePath(FileEntry *file_entry, char *buffer)
 {
   char *sym_name;
 
-  if( mode == DISK_MODE )
+  if( mode == DISK_MODE || mode == USER_MODE )
     return( GetFileNamePath( file_entry, buffer ) );
 
   if( S_ISLNK( file_entry->stat_struct.st_mode ) )
@@ -303,7 +303,7 @@ int InputString(char *s, int y, int x, int length, char *term)
   {
     wmove( stdscr, y, x+p );
 
-    wnoutrefresh( stdscr );
+    RefreshWindow( stdscr );
     doupdate();
 
     c1 = Getch();
@@ -390,7 +390,7 @@ int InputString(char *s, int y, int x, int length, char *term)
                                MvAddStr( y, x, s );
                                for(i=p; i < length; i++)
                                  addch( '_' );
-                               wnoutrefresh( stdscr );
+                               RefreshWindow( stdscr );
                                doupdate();
                              }
                              break;
@@ -442,7 +442,7 @@ int InputString(char *s, int y, int x, int length, char *term)
                                 MvAddStr( y, x, s );
                                 for(i=p; i < length; i++)
                                   addch( '_' );
-                                wnoutrefresh( stdscr );
+                                RefreshWindow( stdscr );
                                 doupdate();
                               }
                               break;
@@ -484,7 +484,7 @@ int InputChoise(char *msg, char *term)
   curs_set(1);
   leaveok(stdscr, FALSE);
   mvprintw( LINES - 2, 1, msg );
-  wnoutrefresh( stdscr );
+  RefreshWindow( stdscr );
   doupdate();
   do
   {
@@ -1235,7 +1235,11 @@ int BuildUserFileEntry(FileEntry *fe_ptr,
       } else if(!strncmp(sptr, GID_VIEWNAME, 3)) {
         n = sprintf(dptr, "%-8s", group_name_ptr);
       } else if(!strncmp(sptr, INODE_VIEWNAME, 3)) {
-        n = sprintf(dptr, "%7ld", fe_ptr->stat_struct.st_ino);
+#ifdef HAS_LONGLONG
+        n = sprintf(dptr, "%7lld", (LONGLONG)fe_ptr->stat_struct.st_ino);
+#else
+        n = sprintf(dptr, "%7ld", (int)fe_ptr->stat_struct.st_ino);
+#endif
       } else if(!strncmp(sptr, ACCTIME_VIEWNAME, 3)) {
         n = sprintf(dptr, "%12s", access_time);
       } else if(!strncmp(sptr, CHGTIME_VIEWNAME, 3)) {
@@ -1255,7 +1259,7 @@ int BuildUserFileEntry(FileEntry *fe_ptr,
       *dptr++ = *sptr++;
     }
   }
-
+  *dptr = '\0';
   strncpy(line, buffer, linelen);
   line[linelen - 1] = '\0';
   return(0);
