@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/view.c,v 1.16 2000/01/01 23:13:53 werner Rel $
+ * $Header: /usr/local/cvsroot/utils/ytree/view.c,v 1.17 2001/02/03 15:58:51 werner Exp $
  *
  * View-Kommando-Bearbeitung
  *
@@ -19,7 +19,8 @@ int View(char *file_path)
 {
   switch( mode )
   {
-    case DISK_MODE :     return( ViewFile( file_path ) );
+    case DISK_MODE :
+    case USER_MODE :     return( ViewFile( file_path ) );
     case TAPE_MODE:
     case RAR_FILE_MODE:
     case RPM_FILE_MODE:
