@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.26 2000/07/15 21:59:27 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.28 2001/04/16 13:34:27 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -448,6 +448,11 @@ extern char *getcwd();
 #define FILEMODE      GetProfileValue( "FILEMODE" )
 #define NUMBERSEP     GetProfileValue( "NUMBERSEP" )
 #define NOSMALLWINDOW GetProfileValue( "NOSMALLWINDOW" )
+#define INITIALDIR    GetProfileValue( "INITIALDIR" )
+#define DIR1          GetProfileValue( "DIR1" )
+#define DIR2          GetProfileValue( "DIR2" )
+#define FILE1         GetProfileValue( "FILE1" )
+#define FILE2         GetProfileValue( "FILE2" )
  
 
 #define DEFAULT_TREE       "."
@@ -459,7 +464,7 @@ extern char *getcwd();
 #define NOTICE( msg )      Notice( msg ) 
 
 #define TAGGED_SYMBOL '*'
-#define MAX_MODES      10
+#define MAX_MODES      11
 #define DISK_MODE      0
 #define LL_FILE_MODE   1
 #define TAR_FILE_MODE  2
@@ -470,6 +475,7 @@ extern char *getcwd();
 #define RPM_FILE_MODE  7
 #define RAR_FILE_MODE  8
 #define TAPE_MODE      9 
+#define USER_MODE      10 
 
 #define NO_COMPRESS                 0
 #define FREEZE_COMPRESS             1
@@ -703,6 +709,8 @@ typedef struct _dir_entry
   struct   stat      stat_struct;
   BOOL               access_denied;
   BOOL               global_flag;
+  BOOL               tagged_flag;
+  BOOL               only_tagged;
   BOOL               not_scanned;
   BOOL               big_window;
   BOOL               login_flag;
@@ -838,6 +846,7 @@ extern BOOL	 print_time;
 extern BOOL      resize_request;
 extern char      number_seperator;
 extern BOOL      bypass_small_window;
+extern char      *initial_directory;
 
 
 #if defined(ultrix)
@@ -856,6 +865,7 @@ extern void DisplayDiskTagged(void);
 extern void DisplayDiskName(void);
 extern void DisplayFileParameter(FileEntry *file_entry);
 extern void DisplayGlobalFileParameter(FileEntry *file_entry);
+extern void RefreshWindow(WINDOW *win);
 extern int  ReadTree(DirEntry *dir_entry, char *path, int depth);
 extern void UnReadTree(DirEntry *dir_entry);
 extern int  ReadTreeFromTAR(DirEntry *dir_entry, FILE *f);
@@ -872,7 +882,7 @@ extern int  GetDiskParameter(char *path,
 			    );
 extern int  HandleDirWindow(DirEntry *start_dir_entry);
 extern void DisplayFileWindow(DirEntry *dir_entry);
-extern int  Init(void);
+extern int Init(char *configuration_file, char *history_file);
 extern char *GetPath(DirEntry *dir_entry, char *buffer);
 extern BOOL Match(char *file_name);
 extern int  SetMatchSpec(char *new_spec);
@@ -1018,4 +1028,10 @@ extern LONGLONG AtoLL(char* cptr);
 extern void DisplayTree(WINDOW *win, int start_entry_no, int hilight_no);
 extern void ReCreateWindows(void);
 extern int  Getch(void);
+extern int  DirUserMode(DirEntry *dir_entry, int ch);
+extern int  FileUserMode(FileEntryList *file_entry_list, int ch);
+extern char *GetUserFileAction(int chkey, int *pchremap);
+extern char *GetUserDirAction(int chkey, int *pchremap);
+extern BOOL IsUserActionDefined(void);
+
 
